Vllm.CollectEnv (VLLM v0.3.0)

Copy Markdown View Source

Submodule bindings for vllm.collect_env.

Version

  • Requested: 0.14.0
  • Observed at generation: 0.14.0

Runtime Options

All functions accept a __runtime__ option for controlling execution behavior:

Vllm.CollectEnv.some_function(args, __runtime__: [timeout: 120_000])

Supported runtime options

  • :timeout - Call timeout in milliseconds (default: 120,000ms / 2 minutes)
  • :timeout_profile - Use a named profile (:default, :ml_inference, :batch_job, :streaming)
  • :stream_timeout - Timeout for streaming operations (default: 1,800,000ms / 30 minutes)
  • :session_id - Override the session ID for this call
  • :pool_name - Target a specific Snakepit pool (multi-pool setups)
  • :affinity - Override session affinity (:hint, :strict_queue, :strict_fail_fast)

Timeout Profiles

  • :default - 2 minute timeout for regular calls
  • :ml_inference - 10 minute timeout for ML/LLM workloads
  • :batch_job - Unlimited timeout for long-running jobs
  • :streaming - 2 minute timeout, 30 minute stream_timeout

Example with timeout override

# For a long-running ML inference call
Vllm.CollectEnv.predict(data, __runtime__: [timeout_profile: :ml_inference])

# Or explicit timeout
Vllm.CollectEnv.predict(data, __runtime__: [timeout: 600_000])

# Route to a pool and enforce strict affinity
Vllm.CollectEnv.predict(data, __runtime__: [pool_name: :strict_pool, affinity: :strict_queue])

See SnakeBridge.Defaults for global timeout configuration.

Summary

Functions

Python binding for vllm.collect_env.check_release_file.

Python module attribute vllm.collect_env.DEFAULT_CONDA_PATTERNS.

Python module attribute vllm.collect_env.DEFAULT_PIP_PATTERNS.

Python module attribute vllm.collect_env.env_info_fmt.

Python module attribute vllm.collect_env.environment_variables.

Python binding for vllm.collect_env.get_cachingallocator_config.

Python binding for vllm.collect_env.get_clang_version.

Python binding for vllm.collect_env.get_cmake_version.

Python binding for vllm.collect_env.get_conda_packages.

Python binding for vllm.collect_env.get_cpu_info.

Python binding for vllm.collect_env.get_cuda_module_loading_config.

Return a list of libcudnn.so; it's hard to tell which one is being used.

Python binding for vllm.collect_env.get_env_info.

Python binding for vllm.collect_env.get_env_vars.

Python binding for vllm.collect_env.get_gcc_version.

Python binding for vllm.collect_env.get_gpu_info.

Python binding for vllm.collect_env.get_gpu_topo.

Python binding for vllm.collect_env.get_libc_version.

Python binding for vllm.collect_env.get_lsb_version.

Python binding for vllm.collect_env.get_mac_version.

Python binding for vllm.collect_env.get_nvidia_driver_version.

Python binding for vllm.collect_env.get_nvidia_smi.

Python binding for vllm.collect_env.get_os.

Return pip list output. Note: will also find conda-installed pytorch and numpy packages.

Python binding for vllm.collect_env.get_platform.

Python binding for vllm.collect_env.get_pretty_env_info.

Python binding for vllm.collect_env.get_python_platform.

Returns the ROCm version if available, otherwise 'N/A'.

Python binding for vllm.collect_env.get_running_cuda_version.

Python binding for vllm.collect_env.get_vllm_version.

Python binding for vllm.collect_env.get_windows_version.

Python binding for vllm.collect_env.is_uv_venv.

Python binding for vllm.collect_env.is_xnnpack_available.

Python binding for vllm.collect_env.main.

Python binding for vllm.collect_env.pretty_str.

Return (return-code, stdout, stderr).

Run command using run_lambda, returns the first regex match if it exists.

Run command using run_lambda; reads and returns entire output if rc is 0.

Run command using run_lambda and returns first line if output is not empty.

Python binding for vllm.collect_env.summarize_vllm_build_flags.

Python module attribute vllm.collect_env.TORCH_AVAILABLE.

Functions

check_release_file(run_lambda, opts \\ [])

@spec check_release_file(
  term(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.check_release_file.

Parameters

  • run_lambda (term())

Returns

  • term()

default_conda_patterns()

@spec default_conda_patterns() ::
  {:ok, MapSet.t(term())} | {:error, Snakepit.Error.t()}

Python module attribute vllm.collect_env.DEFAULT_CONDA_PATTERNS.

Returns

  • MapSet.t(term())

default_pip_patterns()

@spec default_pip_patterns() :: {:ok, MapSet.t(term())} | {:error, Snakepit.Error.t()}

Python module attribute vllm.collect_env.DEFAULT_PIP_PATTERNS.

Returns

  • MapSet.t(term())

env_info_fmt()

@spec env_info_fmt() :: {:ok, String.t()} | {:error, Snakepit.Error.t()}

Python module attribute vllm.collect_env.env_info_fmt.

Returns

  • String.t()

environment_variables()

@spec environment_variables() ::
  {:ok, %{optional(term()) => term()}} | {:error, Snakepit.Error.t()}

Python module attribute vllm.collect_env.environment_variables.

Returns

  • %{optional(term()) => term()}

get_cachingallocator_config(opts \\ [])

@spec get_cachingallocator_config(keyword()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_cachingallocator_config.

Returns

  • term()

get_clang_version(run_lambda, opts \\ [])

@spec get_clang_version(
  term(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_clang_version.

Parameters

  • run_lambda (term())

Returns

  • term()

get_cmake_version(run_lambda, opts \\ [])

@spec get_cmake_version(
  term(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_cmake_version.

Parameters

  • run_lambda (term())

Returns

  • term()

get_conda_packages(run_lambda)

@spec get_conda_packages(term()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_conda_packages.

Parameters

  • run_lambda (term())
  • patterns (term() default: None)

Returns

  • term()

get_conda_packages(run_lambda, opts)

@spec get_conda_packages(
  term(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec get_conda_packages(term(), term()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

get_conda_packages(run_lambda, patterns, opts)

@spec get_conda_packages(term(), term(), keyword()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

get_cpu_info(run_lambda, opts \\ [])

@spec get_cpu_info(
  term(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_cpu_info.

Parameters

  • run_lambda (term())

Returns

  • term()

get_cuda_module_loading_config(opts \\ [])

@spec get_cuda_module_loading_config(keyword()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_cuda_module_loading_config.

Returns

  • term()

get_cudnn_version(run_lambda, opts \\ [])

@spec get_cudnn_version(
  term(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Return a list of libcudnn.so; it's hard to tell which one is being used.

Parameters

  • run_lambda (term())

Returns

  • term()

get_env_info(opts \\ [])

@spec get_env_info(keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_env_info.

Returns

  • term()

get_env_vars(opts \\ [])

@spec get_env_vars(keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_env_vars.

Returns

  • term()

get_gcc_version(run_lambda, opts \\ [])

@spec get_gcc_version(
  term(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_gcc_version.

Parameters

  • run_lambda (term())

Returns

  • term()

get_gpu_info(run_lambda, opts \\ [])

@spec get_gpu_info(
  term(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_gpu_info.

Parameters

  • run_lambda (term())

Returns

  • term()

get_gpu_topo(run_lambda, opts \\ [])

@spec get_gpu_topo(
  term(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_gpu_topo.

Parameters

  • run_lambda (term())

Returns

  • term()

get_libc_version(opts \\ [])

@spec get_libc_version(keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_libc_version.

Returns

  • term()

get_lsb_version(run_lambda, opts \\ [])

@spec get_lsb_version(
  term(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_lsb_version.

Parameters

  • run_lambda (term())

Returns

  • term()

get_mac_version(run_lambda, opts \\ [])

@spec get_mac_version(
  term(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_mac_version.

Parameters

  • run_lambda (term())

Returns

  • term()

get_nvidia_driver_version(run_lambda, opts \\ [])

@spec get_nvidia_driver_version(
  term(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_nvidia_driver_version.

Parameters

  • run_lambda (term())

Returns

  • term()

get_nvidia_smi(opts \\ [])

@spec get_nvidia_smi(keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_nvidia_smi.

Returns

  • term()

get_os(run_lambda, opts \\ [])

@spec get_os(
  term(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_os.

Parameters

  • run_lambda (term())

Returns

  • term()

get_pip_packages(run_lambda)

@spec get_pip_packages(term()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Return pip list output. Note: will also find conda-installed pytorch and numpy packages.

Parameters

  • run_lambda (term())
  • patterns (term() default: None)

Returns

  • term()

get_pip_packages(run_lambda, opts)

@spec get_pip_packages(
  term(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec get_pip_packages(term(), term()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

get_pip_packages(run_lambda, patterns, opts)

@spec get_pip_packages(term(), term(), keyword()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

get_platform(opts \\ [])

@spec get_platform(keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_platform.

Returns

  • term()

get_pretty_env_info(opts \\ [])

@spec get_pretty_env_info(keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_pretty_env_info.

Returns

  • term()

get_python_platform(opts \\ [])

@spec get_python_platform(keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_python_platform.

Returns

  • term()

get_rocm_version(run_lambda, opts \\ [])

@spec get_rocm_version(
  term(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Returns the ROCm version if available, otherwise 'N/A'.

Parameters

  • run_lambda (term())

Returns

  • term()

get_running_cuda_version(run_lambda, opts \\ [])

@spec get_running_cuda_version(
  term(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_running_cuda_version.

Parameters

  • run_lambda (term())

Returns

  • term()

get_vllm_version(opts \\ [])

@spec get_vllm_version(keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_vllm_version.

Returns

  • term()

get_windows_version(run_lambda, opts \\ [])

@spec get_windows_version(
  term(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.get_windows_version.

Parameters

  • run_lambda (term())

Returns

  • term()

is_uv_venv(opts \\ [])

@spec is_uv_venv(keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.is_uv_venv.

Returns

  • term()

is_xnnpack_available(opts \\ [])

@spec is_xnnpack_available(keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.is_xnnpack_available.

Returns

  • term()

main(opts \\ [])

@spec main(keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.main.

Returns

  • term()

pretty_str(envinfo, opts \\ [])

@spec pretty_str(
  term(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.pretty_str.

Parameters

  • envinfo (term())

Returns

  • term()

run(command, opts \\ [])

@spec run(
  term(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Return (return-code, stdout, stderr).

Parameters

  • command (term())

Returns

  • term()

run_and_parse_first_match(run_lambda, command, regex, opts \\ [])

@spec run_and_parse_first_match(term(), term(), term(), keyword()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

Run command using run_lambda, returns the first regex match if it exists.

Parameters

  • run_lambda (term())
  • command (term())
  • regex (term())

Returns

  • term()

run_and_read_all(run_lambda, command, opts \\ [])

@spec run_and_read_all(term(), term(), keyword()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

Run command using run_lambda; reads and returns entire output if rc is 0.

Parameters

  • run_lambda (term())
  • command (term())

Returns

  • term()

run_and_return_first_line(run_lambda, command, opts \\ [])

@spec run_and_return_first_line(term(), term(), keyword()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

Run command using run_lambda and returns first line if output is not empty.

Parameters

  • run_lambda (term())
  • command (term())

Returns

  • term()

summarize_vllm_build_flags(opts \\ [])

@spec summarize_vllm_build_flags(keyword()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.collect_env.summarize_vllm_build_flags.

Returns

  • term()

torch_available()

@spec torch_available() :: {:ok, boolean()} | {:error, Snakepit.Error.t()}

Python module attribute vllm.collect_env.TORCH_AVAILABLE.

Returns

  • boolean()