Vllm.Config.LoRAConfig (VLLM v0.3.0)

Copy Markdown View Source

Configuration for LoRA.

Summary

Types

t()

@opaque t()

Functions

_validate_lora_config(ref, opts \\ [])

@spec _validate_lora_config(
  SnakeBridge.Ref.t(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python method LoRAConfig._validate_lora_config.

Returns

  • term()

compute_hash(ref, opts \\ [])

@spec compute_hash(
  SnakeBridge.Ref.t(),
  keyword()
) :: {:ok, String.t()} | {:error, Snakepit.Error.t()}

WARNING: Whenever a new field is added to this config,

ensure that it is included in the factors list if it affects the computation graph.

Provide a hash that uniquely identifies all the configs that affect the structure of the computation graph from input ids/embeddings to the final hidden states, excluding anything before input ids/embeddings and after the final hidden states.

Returns

  • String.t()

default_mm_loras(ref)

@spec default_mm_loras(SnakeBridge.Ref.t()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

enable_tower_connector_lora(ref)

@spec enable_tower_connector_lora(SnakeBridge.Ref.t()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

fully_sharded_loras(ref)

@spec fully_sharded_loras(SnakeBridge.Ref.t()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

lora_dtype(ref)

@spec lora_dtype(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

max_cpu_loras(ref)

@spec max_cpu_loras(SnakeBridge.Ref.t()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

max_lora_rank(ref)

@spec max_lora_rank(SnakeBridge.Ref.t()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

max_loras(ref)

@spec max_loras(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

new(dataclass_self__, args, kwargs, opts \\ [])

@spec new(term(), term(), term(), keyword()) ::
  {:ok, SnakeBridge.Ref.t()} | {:error, Snakepit.Error.t()}

Constructs LoRAConfig.

Parameters

  • dataclass_self__ (term())
  • args (term())
  • kwargs (term())

verify_with_model_config(ref, model_config, opts \\ [])

@spec verify_with_model_config(SnakeBridge.Ref.t(), term(), keyword()) ::
  {:ok, nil} | {:error, Snakepit.Error.t()}

Python method LoRAConfig.verify_with_model_config.

Parameters

  • model_config (term())

Returns

  • nil