Configuration for observability - metrics and tracing.
Summary
Functions
Handle the legacy case where users might provide a comma-separated
Python method ObservabilityConfig._validate_otlp_traces_endpoint.
Python method ObservabilityConfig._validate_show_hidden_metrics_for_version.
Python method ObservabilityConfig._validate_tracing_config.
WARNING: Whenever a new field is added to this config,
Constructs ObservabilityConfig.
Types
Functions
@spec _validate_collect_detailed_traces(SnakeBridge.Ref.t(), term(), keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
Handle the legacy case where users might provide a comma-separated
string instead of a list of strings.
Parameters
value(term())
Returns
term()
@spec _validate_otlp_traces_endpoint(SnakeBridge.Ref.t(), term(), keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
Python method ObservabilityConfig._validate_otlp_traces_endpoint.
Parameters
value(term())
Returns
term()
@spec _validate_tracing_config( SnakeBridge.Ref.t(), keyword() ) :: {:ok, term()} | {:error, Snakepit.Error.t()}
Python method ObservabilityConfig._validate_tracing_config.
Returns
term()
@spec collect_detailed_traces(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec collect_model_execute_time(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec collect_model_forward_time(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec compute_hash( SnakeBridge.Ref.t(), keyword() ) :: {:ok, String.t()} | {:error, Snakepit.Error.t()}
WARNING: Whenever a new field is added to this config,
ensure that it is included in the factors list if it affects the computation graph.
Provide a hash that uniquely identifies all the configs that affect the structure of the computation graph from input ids/embeddings to the final hidden states, excluding anything before input ids/embeddings and after the final hidden states.
Returns
String.t()
@spec cudagraph_metrics(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec enable_layerwise_nvtx_tracing(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec enable_logging_iteration_details(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec enable_mfu_metrics(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec enable_mm_processor_stats(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec kv_cache_metrics(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec kv_cache_metrics_sample(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec new(term(), term(), term(), keyword()) :: {:ok, SnakeBridge.Ref.t()} | {:error, Snakepit.Error.t()}
Constructs ObservabilityConfig.
Parameters
dataclass_self__(term())args(term())kwargs(term())
@spec otlp_traces_endpoint(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}