Vllm.Config.PoolerConfig (VLLM v0.3.0)

Copy Markdown View Source

Controls the behavior of output pooling in pooling models.

Summary

Types

t()

@opaque t()

Functions

activation(ref)

@spec activation(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

compute_hash(ref, opts \\ [])

@spec compute_hash(
  SnakeBridge.Ref.t(),
  keyword()
) :: {:ok, String.t()} | {:error, Snakepit.Error.t()}

WARNING: Whenever a new field is added to this config,

ensure that it is included in the factors list if it affects the computation graph.

Provide a hash that uniquely identifies all the configs that affect the structure of the computation graph from input ids/embeddings to the final hidden states, excluding anything before input ids/embeddings and after the final hidden states.

Returns

  • String.t()

dimensions(ref)

@spec dimensions(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

enable_chunked_processing(ref)

@spec enable_chunked_processing(SnakeBridge.Ref.t()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

get_seq_pooling_type(ref, opts \\ [])

@spec get_seq_pooling_type(
  SnakeBridge.Ref.t(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python method PoolerConfig.get_seq_pooling_type.

Returns

  • term()

get_tok_pooling_type(ref, opts \\ [])

@spec get_tok_pooling_type(
  SnakeBridge.Ref.t(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python method PoolerConfig.get_tok_pooling_type.

Returns

  • term()

logit_bias(ref)

@spec logit_bias(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

max_embed_len(ref)

@spec max_embed_len(SnakeBridge.Ref.t()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

new(dataclass_self__, args, kwargs, opts \\ [])

@spec new(term(), term(), term(), keyword()) ::
  {:ok, SnakeBridge.Ref.t()} | {:error, Snakepit.Error.t()}

Constructs PoolerConfig.

Parameters

  • dataclass_self__ (term())
  • args (term())
  • kwargs (term())

normalize(ref)

@spec normalize(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

pooling_type(ref)

@spec pooling_type(SnakeBridge.Ref.t()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

returned_token_ids(ref)

@spec returned_token_ids(SnakeBridge.Ref.t()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

seq_pooling_type(ref)

@spec seq_pooling_type(SnakeBridge.Ref.t()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

softmax(ref)

@spec softmax(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

step_tag_id(ref)

@spec step_tag_id(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

tok_pooling_type(ref)

@spec tok_pooling_type(SnakeBridge.Ref.t()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

use_activation(ref)

@spec use_activation(SnakeBridge.Ref.t()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}