Vllm.Config.StructuredOutputsConfig (VLLM v0.3.0)

Copy Markdown View Source

Dataclass which contains structured outputs config for the engine.

Summary

Types

t()

@opaque t()

Functions

_validate_structured_output_config(ref, opts \\ [])

@spec _validate_structured_output_config(
  SnakeBridge.Ref.t(),
  keyword()
) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python method StructuredOutputsConfig._validate_structured_output_config.

Returns

  • term()

backend(ref)

@spec backend(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

compute_hash(ref, opts \\ [])

@spec compute_hash(
  SnakeBridge.Ref.t(),
  keyword()
) :: {:ok, String.t()} | {:error, Snakepit.Error.t()}

WARNING: Whenever a new field is added to this config,

ensure that it is included in the factors list if it affects the computation graph.

Provide a hash that uniquely identifies all the configs that affect the structure of the computation graph from input ids/embeddings to the final hidden states, excluding anything before input ids/embeddings and after the final hidden states.

Returns

  • String.t()

disable_additional_properties(ref)

@spec disable_additional_properties(SnakeBridge.Ref.t()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

disable_any_whitespace(ref)

@spec disable_any_whitespace(SnakeBridge.Ref.t()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

disable_fallback(ref)

@spec disable_fallback(SnakeBridge.Ref.t()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

enable_in_reasoning(ref)

@spec enable_in_reasoning(SnakeBridge.Ref.t()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

new(dataclass_self__, args, kwargs, opts \\ [])

@spec new(term(), term(), term(), keyword()) ::
  {:ok, SnakeBridge.Ref.t()} | {:error, Snakepit.Error.t()}

Constructs StructuredOutputsConfig.

Parameters

  • dataclass_self__ (term())
  • args (term())
  • kwargs (term())

reasoning_parser(ref)

@spec reasoning_parser(SnakeBridge.Ref.t()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

reasoning_parser_plugin(ref)

@spec reasoning_parser_plugin(SnakeBridge.Ref.t()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}