Vllm.Multimodal (VLLM v0.3.0)

Copy Markdown View Source

Submodule bindings for vllm.multimodal.

Version

  • Requested: 0.14.0
  • Observed at generation: 0.14.0

Runtime Options

All functions accept a __runtime__ option for controlling execution behavior:

Vllm.Multimodal.some_function(args, __runtime__: [timeout: 120_000])

Supported runtime options

  • :timeout - Call timeout in milliseconds (default: 120,000ms / 2 minutes)
  • :timeout_profile - Use a named profile (:default, :ml_inference, :batch_job, :streaming)
  • :stream_timeout - Timeout for streaming operations (default: 1,800,000ms / 30 minutes)
  • :session_id - Override the session ID for this call
  • :pool_name - Target a specific Snakepit pool (multi-pool setups)
  • :affinity - Override session affinity (:hint, :strict_queue, :strict_fail_fast)

Timeout Profiles

  • :default - 2 minute timeout for regular calls
  • :ml_inference - 10 minute timeout for ML/LLM workloads
  • :batch_job - Unlimited timeout for long-running jobs
  • :streaming - 2 minute timeout, 30 minute stream_timeout

Example with timeout override

# For a long-running ML inference call
Vllm.Multimodal.predict(data, __runtime__: [timeout_profile: :ml_inference])

# Or explicit timeout
Vllm.Multimodal.predict(data, __runtime__: [timeout: 600_000])

# Route to a pool and enforce strict affinity
Vllm.Multimodal.predict(data, __runtime__: [pool_name: :strict_pool, affinity: :strict_queue])

See SnakeBridge.Defaults for global timeout configuration.

Summary

Functions

Python module attribute vllm.multimodal.__all__.

dict() -> new empty dictionary

Python binding for vllm.multimodal.ModalityData.

A Mapping is a generic container for associating key/value

A Mapping is a generic container for associating key/value

A Mapping is a generic container for associating key/value

Python module attribute vllm.multimodal.MULTIMODAL_REGISTRY.

Python binding for vllm.multimodal.NestedTensors.

Functions

__all__()

@spec __all__() :: {:ok, [term()]} | {:error, Snakepit.Error.t()}

Python module attribute vllm.multimodal.__all__.

Returns

  • list(term())

batched_tensor_inputs(opts \\ [])

@spec batched_tensor_inputs(keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

dict() -> new empty dictionary

dict(mapping) -> new dictionary initialized from a mapping object's (key, value) pairs dict(iterable) -> new dictionary initialized as if via: d = {} for k, v in iterable:

  d[k] = v

dict(**kwargs) -> new dictionary initialized with the name=value pairs in the keyword argument list. For example: dict(one=1, two=2)

Parameters

  • args (term())
  • kwargs (term())

Returns

  • term()

modality_data(opts \\ [])

@spec modality_data(keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.multimodal.ModalityData.

Parameters

  • args (term())
  • kwargs (term())

Returns

  • term()

multi_modal_data_dict(opts \\ [])

@spec multi_modal_data_dict(keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

A Mapping is a generic container for associating key/value

pairs.

This class provides concrete generic implementations of all methods except for getitem, iter, and len.

Parameters

  • args (term())
  • kwargs (term())

Returns

  • term()

multi_modal_placeholder_dict(opts \\ [])

@spec multi_modal_placeholder_dict(keyword()) ::
  {:ok, term()} | {:error, Snakepit.Error.t()}

A Mapping is a generic container for associating key/value

pairs.

This class provides concrete generic implementations of all methods except for getitem, iter, and len.

Parameters

  • args (term())
  • kwargs (term())

Returns

  • term()

multi_modal_uuid_dict(opts \\ [])

@spec multi_modal_uuid_dict(keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

A Mapping is a generic container for associating key/value

pairs.

This class provides concrete generic implementations of all methods except for getitem, iter, and len.

Parameters

  • args (term())
  • kwargs (term())

Returns

  • term()

multimodal_registry()

@spec multimodal_registry() :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python module attribute vllm.multimodal.MULTIMODAL_REGISTRY.

Returns

  • term()

nested_tensors(opts \\ [])

@spec nested_tensors(keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}

Python binding for vllm.multimodal.NestedTensors.

Parameters

  • args (term())
  • kwargs (term())

Returns

  • term()