Dataclass which contains structured outputs config for the engine.
Summary
Functions
Python method StructuredOutputsConfig._validate_structured_output_config.
WARNING: Whenever a new field is added to this config,
Constructs StructuredOutputsConfig.
Types
Functions
@spec _validate_structured_output_config( SnakeBridge.Ref.t(), keyword() ) :: {:ok, term()} | {:error, Snakepit.Error.t()}
Python method StructuredOutputsConfig._validate_structured_output_config.
Returns
term()
@spec backend(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec compute_hash( SnakeBridge.Ref.t(), keyword() ) :: {:ok, String.t()} | {:error, Snakepit.Error.t()}
WARNING: Whenever a new field is added to this config,
ensure that it is included in the factors list if it affects the computation graph.
Provide a hash that uniquely identifies all the configs that affect the structure of the computation graph from input ids/embeddings to the final hidden states, excluding anything before input ids/embeddings and after the final hidden states.
Returns
String.t()
@spec disable_additional_properties(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec disable_any_whitespace(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec disable_fallback(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec enable_in_reasoning(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec new(term(), term(), term(), keyword()) :: {:ok, SnakeBridge.Ref.t()} | {:error, Snakepit.Error.t()}
Constructs StructuredOutputsConfig.
Parameters
dataclass_self__(term())args(term())kwargs(term())
@spec reasoning_parser(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec reasoning_parser_plugin(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}