Adds ANSI color codes to log levels for terminal output.
This formatter adds colors by injecting them into the format string for static elements (timestamp, filename, line number) and modifying the levelname attribute for dynamic color selection.
Summary
Functions
localtime([seconds]) -> (tm_year,tm_mon,tm_mday,tm_hour,tm_min,
Format the specified record as text.
Format and return the specified exception information as a string.
Python method ColoredFormatter.formatMessage.
This method is provided as an extension point for specialized
Return the creation time of the specified LogRecord as formatted text.
Initialize the formatter with specified format strings.
Check if the format uses the creation time of the record.
Types
Functions
@spec colors(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec converter(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
localtime([seconds]) -> (tm_year,tm_mon,tm_mday,tm_hour,tm_min,
tm_sec,tm_wday,tm_yday,tm_isdst)
Convert seconds since the Epoch to a time tuple expressing local time. When 'seconds' is not passed in, convert the current time instead.
Returns
term()
@spec converter( SnakeBridge.Ref.t(), keyword() ) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec converter(SnakeBridge.Ref.t(), term()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec converter(SnakeBridge.Ref.t(), term(), keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec converter(SnakeBridge.Ref.t(), term(), term()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec converter(SnakeBridge.Ref.t(), term(), term(), keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec converter(SnakeBridge.Ref.t(), term(), term(), term()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec converter(SnakeBridge.Ref.t(), term(), term(), term(), keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec converter(SnakeBridge.Ref.t(), term(), term(), term(), term()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec converter(SnakeBridge.Ref.t(), term(), term(), term(), term(), keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec converter(SnakeBridge.Ref.t(), term(), term(), term(), term(), term()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec converter( SnakeBridge.Ref.t(), term(), term(), term(), term(), term(), keyword() ) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec converter(SnakeBridge.Ref.t(), term(), term(), term(), term(), term(), term()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec converter( SnakeBridge.Ref.t(), term(), term(), term(), term(), term(), term(), keyword() ) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec converter( SnakeBridge.Ref.t(), term(), term(), term(), term(), term(), term(), term() ) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec converter( SnakeBridge.Ref.t(), term(), term(), term(), term(), term(), term(), term(), keyword() ) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec converter( SnakeBridge.Ref.t(), term(), term(), term(), term(), term(), term(), term(), term() ) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec default_msec_format(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec default_time_format(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec format(SnakeBridge.Ref.t(), term(), keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
Format the specified record as text.
The record's attribute dictionary is used as the operand to a string formatting operation which yields the returned string. Before formatting the dictionary, a couple of preparatory steps are carried out. The message attribute of the record is computed using LogRecord.getMessage(). If the formatting string uses the time (as determined by a call to usesTime(), formatTime() is called to format the event time. If there is exception information, it is formatted using formatException() and appended to the message.
Parameters
record(term())
Returns
term()
@spec format_exception(SnakeBridge.Ref.t(), term(), keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
Format and return the specified exception information as a string.
This default implementation just uses traceback.print_exception()
Parameters
ei(term())
Returns
term()
@spec format_message(SnakeBridge.Ref.t(), term(), keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
Python method ColoredFormatter.formatMessage.
Parameters
record(term())
Returns
term()
@spec format_stack(SnakeBridge.Ref.t(), term(), keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
This method is provided as an extension point for specialized
formatting of stack information.
The input data is a string as returned from a call to
:func:traceback.print_stack, but with the last trailing newline
removed.
The base implementation just returns the value passed in.
Parameters
stack_info(term())
Returns
term()
@spec format_time(SnakeBridge.Ref.t(), term(), [term()], keyword()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
Return the creation time of the specified LogRecord as formatted text.
This method should be called from format() by a formatter which wants to make use of a formatted time. This method can be overridden in formatters to provide for any specific requirement, but the basic behaviour is as follows: if datefmt (a string) is specified, it is used with time.strftime() to format the creation time of the record. Otherwise, an ISO8601-like (or RFC 3339-like) format is used. The resulting string is returned. This function uses a user-configurable function to convert the creation time to a tuple. By default, time.localtime() is used; to change this for a particular formatter instance, set the 'converter' attribute to a function with the same signature as time.localtime() or time.gmtime(). To change it for all formatters, for example if you want all logging times to be shown in GMT, set the 'converter' attribute in the Formatter class.
Parameters
record(term())datefmt(term() default: None)
Returns
term()
@spec grey(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec new(term(), [term()], keyword()) :: {:ok, SnakeBridge.Ref.t()} | {:error, Snakepit.Error.t()}
Initialize the formatter with specified format strings.
Initialize the formatter either with the specified format string, or a default as described above. Allow for specialized date formatting with the optional datefmt argument. If datefmt is omitted, you get an ISO8601-like (or RFC 3339-like) format.
Use a style parameter of '%', '{' or '$' to specify that you want to
use one of %-formatting, :meth:str.format ({}) formatting or
:class:string.Template formatting in your format string.
.. versionchanged:: 3.2
Added the style parameter.
Parameters
fmt(term())datefmt(term() default: None)style(term() default: '%')
@spec reset(SnakeBridge.Ref.t()) :: {:ok, term()} | {:error, Snakepit.Error.t()}
@spec uses_time( SnakeBridge.Ref.t(), keyword() ) :: {:ok, term()} | {:error, Snakepit.Error.t()}
Check if the format uses the creation time of the record.
Returns
term()