For all pipeline stages except the last, we need to return the hidden
states and residuals to be sent to the next stage. This data structure contains the hidden states and residuals for a request.
Each stage also needs to handle its own kv_connector_output.
Summary
Functions
Sequence and its related classes.
Initialize self. See help(type(self)) for accurate signature.
Types
Functions
@spec items( SnakeBridge.Ref.t(), keyword() ) :: {:ok, term()} | {:error, Snakepit.Error.t()}
Sequence and its related classes.
Returns
term()
@spec new(%{optional(String.t()) => term()}, [term()], keyword()) :: {:ok, SnakeBridge.Ref.t()} | {:error, Snakepit.Error.t()}
Initialize self. See help(type(self)) for accurate signature.
Parameters
tensors(%{optional(String.t()) => term()})kv_connector_output(term() default: None)